@@ -83,7 +83,7 @@ fi
 
 # set defaults, if nothing given
 [[ -z "${KERNEL}" ]] && KERNEL="$(uname -r)"
-[[ -z "${RELEASENAME}" ]] && RELEASENAME="2k14-R1"
+[[ -z "${RELEASENAME}" ]] && RELEASENAME="2k14-R2"
 [[ -z "${IMAGENAME}" ]] && IMAGENAME="Archlinux-allinone-$(date +%Y.%m)"
 
 IMAGENAME_OLD="${IMAGENAME}"
@@ -213,15 +213,15 @@ _download_uefi_shell_tianocore() {
 
 _prepare_uefi_gummiboot_USB_files() {
 	
-	mkdir -p "${ALLINONE}/EFI/boot"
-	cp -f "/usr/lib/gummiboot/gummibootx64.efi" "${ALLINONE}/EFI/boot/loader.efi"
-	cp -f "/usr/lib/gummiboot/gummibootia32.efi" "${ALLINONE}/EFI/boot/bootia32.efi"
+	mkdir -p "${ALLINONE}/EFI/BOOT"
+	cp -f "/usr/lib/gummiboot/gummibootx64.efi" "${ALLINONE}/EFI/BOOT/loader.efi"
+	# cp -f "/usr/lib/gummiboot/gummibootia32.efi" "${ALLINONE}/EFI/BOOT/BOOTIA32.EFI"
 	
 	mkdir -p "${ALLINONE}/loader/entries"
 	
 	cat << GUMEOF > "${ALLINONE}/loader/loader.conf"
-timeout  5
-default  default*
+timeout  4
+default  default-*
 GUMEOF
 	
 	cat << GUMEOF > "${ALLINONE}/loader/entries/archboot-x86_64-efistub.conf"
@@ -232,13 +232,13 @@ options         cgroup_disable=memory loglevel=7 add_efi_memmap _X64_UEFI=1
 architecture    x64
 GUMEOF
 	
-	cat << GUMEOF > "${ALLINONE}/loader/entries/archboot-i686-efistub.conf"
-title           Arch Linux i686 Archboot EFISTUB
-linux           /boot/vmlinuz_i686
-initrd          /boot/initramfs_i686.img
-options         cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
-architecture    ia32
-GUMEOF
+	# cat << GUMEOF > "${ALLINONE}/loader/entries/archboot-i686-efistub.conf"
+# title           Arch Linux i686 Archboot EFISTUB
+# linux           /boot/vmlinuz_i686
+# initrd          /boot/initramfs_i686.img
+# options         cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
+# architecture    ia32
+# GUMEOF
 	
 	cat << GUMEOF > "${ALLINONE}/loader/entries/uefi-shell-x64-v2.conf"
 title           UEFI Shell X64 v2
@@ -252,17 +252,17 @@ efi             /EFI/tools/shellx64_v1.efi
 architecture    x64
 GUMEOF
 	
-	cat << GUMEOF > "${ALLINONE}/loader/entries/uefi-shell-ia32-v2.conf"
-title           UEFI Shell IA32 v2
-efi             /EFI/tools/shellia32_v2.efi
-architecture    ia32
-GUMEOF
-	
-	cat << GUMEOF > "${ALLINONE}/loader/entries/uefi-shell-ia32-v1.conf"
-title           UEFI Shell IA32 v1
-efi             /EFI/tools/shellia32_v1.efi
-architecture    ia32
-GUMEOF
+	# cat << GUMEOF > "${ALLINONE}/loader/entries/uefi-shell-ia32-v2.conf"
+# title           UEFI Shell IA32 v2
+# efi             /EFI/tools/shellia32_v2.efi
+# architecture    ia32
+# GUMEOF
+	 
+	# cat << GUMEOF > "${ALLINONE}/loader/entries/uefi-shell-ia32-v1.conf"
+# title           UEFI Shell IA32 v1
+# efi             /EFI/tools/shellia32_v1.efi
+# architecture    ia32
+# GUMEOF
 	
 	cat << GUMEOF > "${ALLINONE}/loader/entries/grub-x64-gummiboot.conf"
 title           GRUB X64 - if EFISTUB boot fails
@@ -270,14 +270,14 @@ efi             /EFI/grub/grubx64.efi
 architecture    x64
 GUMEOF
 	
-	cat << GUMEOF > "${ALLINONE}/loader/entries/syslinux-ia32-gummiboot.conf"
-title           Syslinux IA32 - for x86_64 kernel boot
-efi             /EFI/syslinux/efi32/syslinux.efi
-architecture    ia32
-GUMEOF
+	# cat << GUMEOF > "${ALLINONE}/loader/entries/syslinux-ia32-gummiboot.conf"
+# title           Syslinux IA32 - for x86_64 kernel boot
+# efi             /EFI/syslinux/efi32/syslinux.efi
+# architecture    ia32
+# GUMEOF
 	
 	mv "${ALLINONE}/loader/entries/archboot-x86_64-efistub.conf" "${ALLINONE}/loader/entries/default-x64.conf"
-	mv "${ALLINONE}/loader/entries/syslinux-ia32-gummiboot.conf" "${ALLINONE}/loader/entries/default-ia32.conf"
+	# mv "${ALLINONE}/loader/entries/syslinux-ia32-gummiboot.conf" "${ALLINONE}/loader/entries/default-ia32.conf"
 	
 }
 
@@ -286,7 +286,7 @@ _prepare_uefi_X64_GRUB_USB_files() {
 	mkdir -p "${ALLINONE}/EFI/grub"
 	
 	echo 'configfile ${cmdpath}/grubx64.cfg' > /tmp/grubx64.cfg
-	grub-mkstandalone -d /usr/lib/grub/x86_64-efi/ -O x86_64-efi --modules="part_gpt part_msdos" --fonts="unicode" --locales="en@quot" --themes="" -o "${ALLINONE}/EFI/grub/grubx64.efi"  "/boot/grub/grub.cfg=/tmp/grubx64.cfg" -v
+	grub-mkstandalone -d /usr/lib/grub/x86_64-efi/ -O x86_64-efi --modules="part_gpt part_msdos" --fonts="unicode" --locales="en@quot" --themes="" -o "${ALLINONE}/EFI/grub/grubx64.efi" "boot/grub/grub.cfg=/tmp/grubx64.cfg" -v
 	
 	cat << GRUBEOF > "${ALLINONE}/EFI/grub/grubx64.cfg"
 insmod part_gpt
@@ -307,6 +307,9 @@ if loadfont "${prefix}/fonts/unicode.pf2" ; then
     terminal_output gfxterm
 fi
 
+set default="Arch Linux x86_64 Archboot Non-EFISTUB"
+set timeout="2"
+
 menuentry "Arch Linux x86_64 Archboot Non-EFISTUB" {
     set gfxpayload=keep
     search --no-floppy --set=root --file /boot/vmlinuz_x86_64
@@ -331,6 +334,71 @@ GRUBEOF
 	
 }
 
+_prepare_uefi_IA32_GRUB_USB_files() {
+	
+	mkdir -p "${ALLINONE}/EFI/BOOT"
+	
+	echo 'configfile ${cmdpath}/bootia32.cfg' > /tmp/bootia32.cfg
+	grub-mkstandalone -d /usr/lib/grub/i386-efi/ -O i386-efi --modules="part_gpt part_msdos" --fonts="unicode" --locales="en@quot" --themes="" -o "${ALLINONE}/EFI/BOOT/BOOTIA32.EFI" "boot/grub/grub.cfg=/tmp/bootia32.cfg" -v
+	
+	cat << GRUBEOF > "${ALLINONE}/EFI/BOOT/bootia32.cfg"
+insmod part_gpt
+insmod part_msdos
+insmod fat
+
+insmod efi_gop
+insmod efi_uga
+insmod video_bochs
+insmod video_cirrus
+
+insmod font
+
+if loadfont "${prefix}/fonts/unicode.pf2" ; then
+    insmod gfxterm
+    set gfxmode="1366x768x32;1280x800x32;1024x768x32;auto"
+    terminal_input console
+    terminal_output gfxterm
+fi
+
+set default="Arch Linux x86_64 Archboot - EFI MIXED MODE"
+set timeout="2"
+
+menuentry "Arch Linux x86_64 Archboot - EFI MIXED MODE" {
+    set gfxpayload=keep
+    search --no-floppy --set=root --file /boot/vmlinuz_x86_64
+    linux /boot/vmlinuz_x86_64 cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
+    initrd /boot/initramfs_x86_64.img
+}
+
+menuentry "Arch Linux i686 Archboot Non-EFISTUB" {
+    set gfxpayload=keep
+    search --no-floppy --set=root --file /boot/vmlinuz_i686
+    linux /boot/vmlinuz_i686 cgroup_disable=memory loglevel=7 add_efi_memmap _IA32_UEFI=1
+    initrd /boot/initramfs_i686.img
+}
+
+# menuentry "Syslinux for x86_64 Kernel in IA32 UEFI" {
+    # search --no-floppy --set=root --file /EFI/syslinux/efi32/syslinux.efi
+    # chainloader /EFI/syslinux/efi32/syslinux.efi
+# }
+
+menuentry "UEFI Shell IA32 v2" {
+    search --no-floppy --set=root --file /EFI/tools/shellia32_v2.efi
+    chainloader /EFI/tools/shellia32_v2.efi
+}
+
+menuentry "UEFI Shell IA32 v1" {
+    search --no-floppy --set=root --file /EFI/tools/shellia32_v1.efi
+    chainloader /EFI/tools/shellia32_v1.efi
+}
+
+menuentry "Exit GRUB" {
+    exit
+}
+GRUBEOF
+	
+}
+
 _prepare_uefi_IA32_syslinux_USB_files() {
 	
 	mkdir -p "${ALLINONE}/EFI/syslinux"
@@ -379,7 +447,9 @@ _prepare_uefi_gummiboot_USB_files
 
 _prepare_uefi_X64_GRUB_USB_files
 
-_prepare_uefi_IA32_syslinux_USB_files
+_prepare_uefi_IA32_GRUB_USB_files
+
+# _prepare_uefi_IA32_syslinux_USB_files
 
 # place syslinux files
 mv "${CORE}/tmp"/*/boot/syslinux/* "${ALLINONE}/boot/syslinux/"
